![license](https://img.shields.io/github/license/Eve-ning/reamberPy)
![dls](https://img.shields.io/pypi/dm/reamber)
![codecov-coverage](https://img.shields.io/codecov/c/github/Eve-ning/reamberPy)
![codefactor](https://img.shields.io/codefactor/grade/github/Eve-ning/reamberPy)
![version](https://img.shields.io/pypi/v/reamber)

# Reamber (Py) 

[:blue_book: Wiki](https://eve-ning.github.io/reamberPy/index.html) & [Getting Started](https://eve-ning.github.io/reamberPy/info/GettingStarted.html)

`pip install reamber`

------

VSRG Toolbox for data extraction, manipulation & analysis.

# Features

- Game Support: osu!mania, StepMania, BMS and partially O2Jam files.
- Algorithms: Map IO, Conversion, Map Image Generation, Pattern Extraction
- Data Architecture: Pandas DataFrame Integration

> This is built on pandas `DataFrame`, thus, if you need more control, you can 
retrieve the underlying `DataFrame` via the `.df` property on many reamber classes. 

# Status

This is now in 1.0.0, though I don't plan to actively develop it further.

## For Developers, By Developers

A growing amount of osu!mania players are interested in programming.
The best way to learn is to relate it to something that you're familiar with.

That's why I'm making a library that allows you to tamper with your favorite
games, and learn on the way.

